@@ -1,23 +1,8 @@
 #!/usr/bin/env perl
 
-# Copyright (C) 2012 by CPqD
-
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 package Git::Hooks::CheckJira;
 {
-  $Git::Hooks::CheckJira::VERSION = '0.047';
+  $Git::Hooks::CheckJira::VERSION = '0.048';
 }
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages.
 
@@ -29,7 +14,7 @@ use Git::Hooks qw/:DEFAULT :utils/;
 use File::Slurp;
 use Data::Util qw(:check);
 use List::MoreUtils qw/uniq/;
-use JIRA::Client;
+use JIRA::REST;
 
 my $PKG = __PACKAGE__;
 (my $CFG = __PACKAGE__) =~ s/.*::/githooks./;
@@ -92,7 +77,7 @@ sub _jira {
         }
         $jira{jiraurl} =~ s:/+$::; # trim trailing slashes from the URL
 
-        my $jira = eval { JIRA::Client->new($jira{jiraurl}, $jira{jirauser}, $jira{jirapass}) };
+        my $jira = eval { JIRA::REST->new($jira{jiraurl}, $jira{jirauser}, $jira{jirapass}) };
         length $@
             and $git->error($PKG, "cannot connect to the JIRA server at '$jira{jiraurl}' as '$jira{jirauser}': $@\n")
                 and return;
@@ -102,7 +87,7 @@ sub _jira {
     return $cache->{jira};
 }
 
-# Returns a JIRA::Client object or undef if there is any problem
+# Returns a JIRA::REST object or undef if there is any problem
 
 sub get_issue {
     my ($git, $key) = @_;
@@ -113,7 +98,7 @@ sub get_issue {
 
     # Try to get the issue from the cache
     unless (exists $cache->{keys}{$key}) {
-        $cache->{keys}{$key} = eval { $jira->getIssue($key) };
+        $cache->{keys}{$key} = eval { $jira->GET("/issue/$key") };
         length $@
             and $git->error($PKG, "cannot get issue $key: $@\n")
                 and return;
@@ -181,7 +166,7 @@ sub _check_jira_keys {
             or $errors++
                 and next KEY;
 
-        if ($unresolved && defined $issue->{resolution}) {
+        if ($unresolved && defined $issue->{fields}{resolution}) {
             $git->error($PKG, ferror($key, $commit, $ref, "is already resolved"));
             $errors++;
             next KEY;
@@ -193,9 +178,11 @@ sub _check_jira_keys {
                     and $errors++
                         and next KEY;
 
-            $user eq $issue->{assignee}
+            my $assignee = $issue->{fields}{assignee}{name};
+
+            $user eq $assignee
                 or $git->error($PKG, ferror($key, $commit, $ref,
-                                            "is currently assigned to '$issue->{assignee}' but should be assigned to you ($user)"))
+                                            "is currently assigned to '$assignee' but should be assigned to you ($user)"))
                     and $errors++
                         and next KEY;
         }
@@ -344,7 +331,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 DESCRIPTION
 
@@ -433,18 +420,18 @@ documentation to understand it.
 =head2 githooks.checkjira.jiraurl URL
 
 This option specifies the JIRA server HTTP URL, used to construct the
-C<JIRA::Client> object which is used to interact with your JIRA
-server. Please, see the JIRA::Client documentation to know about them.
+C<JIRA::REST> object which is used to interact with your JIRA
+server. Please, see the JIRA::REST documentation to know about them.
 
 =head2 githooks.checkjira.jirauser USERNAME
 
 This option specifies the JIRA server username, used to construct the
-C<JIRA::Client> object.
+C<JIRA::REST> object.
 
 =head2 githooks.checkjira.jirapass PASSWORD
 
 This option specifies the JIRA server password, used to construct the
-C<JIRA::Client> object.
+C<JIRA::REST> object.
 
 =head2 githooks.checkjira.matchkey REGEXP
 
@@ -458,11 +445,14 @@ this option to a suitable regex to match a complete JIRA issue key.
 
 =head2 githooks.checkjira.matchlog REGEXP
 
-By default, JIRA keys are looked for in all of the commit
-message. However, this can lead to some false positives, since the
-default issue pattern can match other things besides JIRA issue
-keys. You may use this option to restrict the places inside the commit
-message where the keys are going to be looked for.
+By default, JIRA keys are looked for in all of the commit message. However,
+this can lead to some false positives, since the default issue pattern can
+match other things besides JIRA issue keys. You may use this option to
+restrict the places inside the commit message where the keys are going to be
+looked for. You do this by specifying a regular expression with a capture
+group (a pair of parenthesis) in it. The commit message is matched against
+the regular expression and the JIRA tickets are looked for only within the
+part that matched the capture group.
 
 Here are some examples:
 
@@ -541,7 +531,15 @@ because there is no commit yet.
 
 =item * B<JIRA>
 
-The JIRA::Client object used to talk to the JIRA server.
+The JIRA::REST object used to talk to the JIRA server.
+
+Note that up to version 0.047 of Git::Hooks::CheckJira this used to be a
+JIRA::Client object, which uses JIRA's SOAP API which was deprecated on JIRA
+6.0 and won't be available anymore on JIRA 7.0.
+
+If you have code relying on the JIRA::Client module you're advised to
+rewrite it using the JIRA::REST module. As a stopgap measure you can
+disregard the JIRA::REST object and create your own JIRA::Client object.
 
 =item * B<ISSUES...>
 
@@ -582,15 +580,28 @@ arguments passed to the hook by Gerrit.
 
 =head1 SEE ALSO
 
-B<Git::More>
+=over
 
-B<JIRA::Client>
+=item * L<Git::More>
+
+=item * L<JIRA::REST>
+
+=item * L<JIRA::Client>
+
+=back
 
 =head1 REFERENCES
 
-This script is heavily inspired (and sometimes derived) from Joyjit
+=over
+
+=item This script is heavily inspired (and sometimes derived) from Joyjit
 Nath's L<git-jira-hook|https://github.com/joyjit/git-jira-hook>.
 
+=item L<JIRA SOAP API deprecation
+notice|https://developer.atlassian.com/display/JIRADEV/SOAP+and+XML-RPC+API+Deprecated+in+JIRA+6.0>
+
+=back
+
 =head1 AUTHOR
 
 Gustavo L. de M. Chaves <gnustavo@cpan.org>
